svn commit: r335498 - head/sys/libkern

Conrad Meyer cem at FreeBSD.org
Thu Jun 21 17:35:14 UTC 2018


Author: cem
Date: Thu Jun 21 17:35:13 2018
New Revision: 335498
URL: https://svnweb.freebsd.org/changeset/base/335498

Log:
  Sync strlcpy with userland version, again
  
  No functional change.
  
  Please remember to update libkern copies of libc functions when you update
  libc.
  
  Sponsored by:	Dell EMC Isilon

Modified:
  head/sys/libkern/strlcpy.c

Modified: head/sys/libkern/strlcpy.c
==============================================================================
--- head/sys/libkern/strlcpy.c	Thu Jun 21 17:24:10 2018	(r335497)
+++ head/sys/libkern/strlcpy.c	Thu Jun 21 17:35:13 2018	(r335498)
@@ -1,7 +1,7 @@
-/*	$OpenBSD: strlcpy.c,v 1.11 2006/05/05 15:27:38 millert Exp $	*/
+/*	$OpenBSD: strlcpy.c,v 1.12 2015/01/15 03:54:12 millert Exp $	*/
 
-/*-
- * Copyright (c) 1998 Todd C. Miller <Todd.Miller at courtesan.com>
+/*
+ * Copyright (c) 1998, 2015 Todd C. Miller <Todd.Miller at courtesan.com>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -23,32 +23,31 @@ __FBSDID("$FreeBSD$");
 #include <sys/libkern.h>
 
 /*
  * Copy src to string dst of size siz.  At most siz-1 characters
  * will be copied.  Always NUL terminates (unless siz == 0).
  * Returns strlen(src); if retval >= siz, truncation occurred.
  */
 size_t
-strlcpy(char * __restrict dst, const char * __restrict src, size_t siz)
+strlcpy(char * __restrict dst, const char * __restrict src, size_t dsize)
 {
-	char *d = dst;
-	const char *s = src;
-	size_t n = siz;
+	const char *osrc = src;
+	size_t nleft = dsize;
 
-	/* Copy as many bytes as will fit */
-	if (n != 0) {
-		while (--n != 0) {
-			if ((*d++ = *s++) == '\0')
+	/* Copy as many bytes as will fit. */
+	if (nleft != 0) {
+		while (--nleft != 0) {
+			if ((*dst++ = *src++) == '\0')
 				break;
 		}
 	}
 
-	/* Not enough room in dst, add NUL and traverse rest of src */
-	if (n == 0) {
-		if (siz != 0)
-			*d = '\0';		/* NUL-terminate dst */
-		while (*s++)
+	/* Not enough room in dst, add NUL and traverse rest of src. */
+	if (nleft == 0) {
+		if (dsize != 0)
+			*dst = '\0';		/* NUL-terminate dst */
+		while (*src++)
 			;
 	}
 
-	return(s - src - 1);	/* count does not include NUL */
+	return(src - osrc - 1);	/* count does not include NUL */
 }
@@ -23,32 +23,31 @@ __FBSDID("$FreeBSD$");
 
 /*
- * Copy src to string dst of size siz.  At most siz-1 characters
- * will be copied.  Always NUL terminates (unless siz == 0).
- * Returns strlen(src); if retval >= siz, truncation occurred.
+ * Copy string src to buffer dst of size dsize.  At most dsize-1
+ * chars will be copied.  Always NUL terminates (unless dsize == 0).
+ * Returns strlen(src); if retval >= dsize, truncation occurred.
  */
 size_t


More information about the svn-src-all mailing list